"""
Discord.py ThiccStatus Cog implementation
Copyright IsThicc Software 2020-2021
You should have received a copy of the Apache Version 2.0 license 
along with this program. If you didn't, please alert <board@isthicc.dev>
"""

raise SystemExit("This module cannot be imported in it's current state. " 
                 "View more here: https://github.com/IsThicc/ThiccStatusDiscord")



from setuptools import setup, find_packages

setup(
    name='ThiccStatus',
    version='1.0.0',
    lisence='Apache Version 2.0',
    description='Discord module for ThiccStatus.',
    long_description=open("README.md", "r").read(),
    long_description_content_type='text/markdown',
    url='https://isthicc.dev/',
    author='IsThicc Software',
    packages=find_packages(),
    install_requires=['discord','aiohttp']
)
